AsChildrenSlice

Trait AsChildrenSlice 

pub trait AsChildrenSlice {
    type Child;

    // Required method
    fn as_children_slice(&self) -> &[Self::Child];
}
Represents a trait that provides the ability to get the children of an element as a slice

Required Associated Types

type Child

The type of child contained within

Required Methods

fn as_children_slice(&self) -> &[Self::Child]

Returns a slice to children contained within

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors