pub trait IntoChildren {
type Child;
// Required method
fn into_children(self) -> Vec<Self::Child>;
}Expand description
Represents a trait that provides the ability to get the children of an element through a consuming conversion
Required Associated Types
Required Methods
Sourcefn into_children(self) -> Vec<Self::Child>
fn into_children(self) -> Vec<Self::Child>
Returns a vec of children contained within
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".